@@ -22,7 +22,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <chm_lib.h>
+#include <gtk/gtktypeutils.h>
 
 typedef struct _ChmFile       ChmFile;
 typedef struct _ChmFileClass  ChmFileClass;
@@ -50,7 +50,7 @@ struct _ChmFile
         gchar          *hhc;
         gchar          *hhk;
         gchar          *title;
-        gchar          *encoding;
+        const gchar    *encoding;
         gchar          *variable_font;
         gchar          *fixed_font;
 
@@ -66,4 +66,4 @@ struct _ChmFileClass
 GtkType chmfile_get_type(void);
 ChmFile *chmfile_new(const gchar *);
 
-#endif /* !__CHMFILE_H__ */ 
+#endif /* !__CHMFILE_H__ */
