@@ -17,10 +17,11 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include <config.h>
+#include "config.h"
+#include "link.h"
+
 #include <string.h>
 
-#include "link.h"
 #include "utils.h"
 
 Link *
