@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge.com>
+ *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,6 +26,3 @@
 GNode *parse_hhc_file(const gchar *, const gchar *);
 
 #endif /* !__PARSER_H__ */
-
-/* arch-tag: 16c36a76-fce9-11da-92c5-00e04c516bee
-   (do not change this comment) */
