@@ -17,6 +17,8 @@
  *  Boston, MA 02110-1301, USA.
  */
 
+#include "utils.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -25,7 +27,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include "utils.h"
 #include "link.h"
 
 static gint parse_config_line(gchar *, gchar *, gchar *);
@@ -175,7 +176,7 @@ save_option(FILE *file, const gchar *id, const gchar *value)
         gchar *p;
 
         p = g_strdup_printf("%s=%s\n", id, value);
-        fprintf(file, p);
+        fputs(p, file);
 
         g_free(p);
 }
